summaryrefslogtreecommitdiffstats
path: root/src/sound/MappedComposition.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sound/MappedComposition.h')
-rw-r--r--src/sound/MappedComposition.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/sound/MappedComposition.h b/src/sound/MappedComposition.h
index bfa7c05..a7e03fd 100644
--- a/src/sound/MappedComposition.h
+++ b/src/sound/MappedComposition.h
@@ -25,7 +25,7 @@
// MappedComposition is used with MappedEvent to create a sequence
// of MIDI ready events ready for playing. The QDataStream operators
// are a necessary part of the DCOP transmission process allowing
// the whole class to be serialized. The core application is sent
// a request specifying a time slice between given start and end
@@ -36,7 +36,7 @@
#include <Composition.h>
#include "MappedEvent.h"
#include <set>
-#include <qdatastream.h>
+#include <tqdatastream.h>
namespace Rosegarden
{
@@ -71,10 +71,10 @@ public:
// This section is used for serialising this class over DCOP
//
//
- friend QDataStream& operator>>(QDataStream &dS, MappedComposition *mC);
- friend QDataStream& operator<<(QDataStream &dS, MappedComposition *mC);
- friend QDataStream& operator>>(QDataStream &dS, MappedComposition &mC);
- friend QDataStream& operator<<(QDataStream &dS, const MappedComposition &mC);
+ friend TQDataStream& operator>>(TQDataStream &dS, MappedComposition *mC);
+ friend TQDataStream& operator<<(TQDataStream &dS, MappedComposition *mC);
+ friend TQDataStream& operator>>(TQDataStream &dS, MappedComposition &mC);
+ friend TQDataStream& operator<<(TQDataStream &dS, const MappedComposition &mC);
// Clear out
void clear();
@@ -25,7 +25,7 @@
// MappedComposition is used with MappedEvent to create a sequence
-// of MIDI ready events ready for playing. The QDataStream operators
+// of MIDI ready events ready for playing. The TQDataStream operators
// are a necessary part of the DCOP transmission process allowing
// the whole class to be serialized. The core application is sent